@@ -201,36 +201,48 @@ func (c *documentationCommand) writeDocs(folder string, superCommands []string,
 		if !printDefaultCommands && isDefaultCommand(name) {
 			continue
 		}
+
 		commandSeq := append(superCommands, name)
-		target := fmt.Sprintf("%s.md", strings.Join(commandSeq[1:], "_"))
-		target = strings.ReplaceAll(target, " ", "_")
-		target = filepath.Join(folder, target)
 
-		f, err := os.Create(target)
-		if err != nil {
-			return err
-		}
-		writer := bufio.NewWriter(f)
-		formatted := c.formatCommand(ref, false, commandSeq)
-		_, err = writer.WriteString(formatted)
-		if err != nil {
-			return err
-		}
-		writer.Flush()
-		f.Close()
-
-		// Handle subcommands
-		if sc, ok := ref.command.(*SuperCommand); ok {
-			err = sc.documentation.writeDocs(folder, commandSeq, false)
-			if err != nil {
+		sc, isSuperCommand := ref.command.(*SuperCommand)
+		if !isSuperCommand || (isSuperCommand && !sc.SkipCommandDoc) {
+			target := fmt.Sprintf("%s.md", strings.Join(commandSeq[1:], "_"))
+			if err := c.writeDoc(folder, target, ref, commandSeq); err != nil {
 				return err
 			}
 		}
+
+		// Handle subcommands
+		if !isSuperCommand {
+			continue
+		}
+
+		if err := sc.documentation.writeDocs(folder, commandSeq, false); err != nil {
+			return err
+		}
 	}
 
 	return nil
 }
 
+func (c *documentationCommand) writeDoc(folder, target string, ref commandReference, commandSeq []string) error {
+	target = strings.ReplaceAll(target, " ", "_")
+	target = filepath.Join(folder, target)
+
+	f, err := os.Create(target)
+	if err != nil {
+		return err
+	}
+	defer func() { _ = f.Close() }()
+
+	formatted := c.formatCommand(ref, false, commandSeq)
+	if _, err = fmt.Fprintln(f, formatted); err != nil {
+		return err
+	}
+	_ = f.Sync()
+	return nil
+}
+
 func (c *documentationCommand) readFileIds(path string) (map[string]string, error) {
 	f, err := os.Open(path)
 	if err != nil {
@@ -277,17 +289,22 @@ func (c *documentationCommand) writeSections(w io.Writer, superCommands []string
 		}
 		ref := c.super.subcmds[name]
 		commandSeq := append(superCommands, name)
-		_, err := fmt.Fprintf(w, "%s", c.formatCommand(ref, true, commandSeq))
-		if err != nil {
-			return err
+
+		// This is a bit messy, because we want to keep the order of the
+		// documentation the same.
+		sc, isSuperCommand := ref.command.(*SuperCommand)
+		if !isSuperCommand || (isSuperCommand && !sc.SkipCommandDoc) {
+			if _, err := fmt.Fprintf(w, "%s", c.formatCommand(ref, true, commandSeq)); err != nil {
+				return err
+			}
 		}
 
 		// Handle subcommands
-		if sc, ok := ref.command.(*SuperCommand); ok {
-			err = sc.documentation.writeSections(w, commandSeq, false)
-			if err != nil {
-				return err
-			}
+		if !isSuperCommand {
+			continue
+		}
+		if err := sc.documentation.writeSections(w, commandSeq, false); err != nil {
+			return err
 		}
 	}
 	return nil
@@ -484,7 +501,9 @@ func (d *documentationCommand) formatFlags(c Command, info *Info) string {
 			theFlags += fmt.Sprintf("`--%s`", f.Name)
 		}
 		formatted += fmt.Sprintf("| %s | %s | %s |\n", theFlags,
-			EscapeMarkdown(fs[0].DefValue), EscapeMarkdown(fs[0].Usage))
+			EscapeMarkdown(fs[0].DefValue),
+			strings.ReplaceAll(EscapeMarkdown(fs[0].Usage), "\n", " "),
+		)
 	}
 	return formatted
 }
