@@ -7,8 +7,8 @@ func NewVersionCommand(version string, versionDetail interface{}) Command {
 	return newVersionCommand(version, versionDetail)
 }
 
-func FormatCommand(command Command, super *SuperCommand, title bool) string {
+func FormatCommand(command Command, super *SuperCommand, title bool, commandSeq []string) string {
 	docCmd := &documentationCommand{super: super}
 	ref := commandReference{command: command}
-	return docCmd.formatCommand(ref, title)
+	return docCmd.formatCommand(ref, title, commandSeq)
 }
